@@ -6,16 +6,13 @@ set -o xtrace
 
 echo_summary "zun's plugin.sh was called..."
 source $DEST/zun/devstack/lib/zun
-source $DEST/zun/devstack/lib/nova
 (set -o posix; set)
 
 if is_service_enabled zun-api zun-compute; then
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
         echo_summary "Installing zun"
-        install_docker
         install_zun
 
-        LIBS_FROM_GIT="${LIBS_FROM_GIT},python-zunclient"
         install_zunclient
         cleanup_zun
 
@@ -27,10 +24,6 @@ if is_service_enabled zun-api zun-compute; then
             create_zun_accounts
         fi
 
-        if [[ ${ZUN_DRIVER} == "nova-docker" ]]; then
-            configure_nova_docker
-        fi
-
     elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
         # Initialize zun
         init_zun
@@ -38,7 +31,7 @@ if is_service_enabled zun-api zun-compute; then
         # Start the zun API and zun compute
         echo_summary "Starting zun"
         start_zun
-        upload_sandbox_image
+        upload_images
 
     fi
 
